require "math"

MapLoader = {}

function MapLoader:load( filepath )
	local mapLuaFile = love.filesystem.load( filepath )
	local mapdata = mapLuaFile()
	local tileset = self:loadTiles( mapdata.tilesets[1] )
	local mainLayer = mapdata.layers[1]
	local tilemap   = mainLayer.data

	local map = entityManager:createEntity('map')
	entityManager:addComponentToEntity( map, MapAttribute( mapdata, tileset, tilemap ) )
	entityManager:refreshEntity( map )

	return map
end

--TODO: Migrate to geometry instead of quad
function MapLoader:loadTiles( tileset )
	local graphics = love.graphics
	local quads 	  = {}
	local numberOfTiles = math.floor( math.sqrt( (tileset.imageheight / tileset.tileheight) * (tileset.imagewidth / tileset.tilewidth) ) )
	local image 	  = graphics.newImage( tileset.image )
	local spriteBatch = graphics.newSpriteBatch( image, 1000, "static" )
	
	local i = 1
	for y = 0, math.floor(tileset.imageheight / tileset.tileheight)-1 do --for every row
		for x = 0, math.floor(tileset.imagewidth / tileset.tilewidth)-1 do --for every column
			quads[i] = graphics.newQuad(
				(x * tileset.tilewidth)+(tileset.margin*(x+1)),
				(y * tileset.tileheight)+(tileset.margin*(y+1)), 
				tileset.tilewidth, tileset.tileheight,
				tileset.imagewidth, tileset.imageheight
			)
			i = i + 1
		end
	end

	return {
		['data'] = tileset;
		['quads'] = quads;
		['spriteBatch'] = spriteBatch;
	}
end

return MapLoader